@@ -725,3 +725,105 @@ MESSAGES.append(
         ("Yes", "確認"),
     )
 )
+
+MESSAGES.append(
+    # Dutch translation (nl, nl_nl, nl_be)
+    LocaleMsgs(
+        "nl",
+        ("OK", "OK"),
+        ("Ok", "Ok"),
+        ("Continue", "Verder"),
+        ("Retry", "Herhalen"),
+        ("Delete", "Verwijderen"),
+        ("Next", "Volgende"),
+        ("Prev", "Vorige"),
+        ("Yes", "Ja"),
+        ("No", "Nee"),
+        ("Open", "Openen"),
+        ("Close", "Sluiten"),
+        ("Add", "Toevoegen"),
+        ("Remove", "Verwijderen"),
+        ("Submit", "OK"),
+        ("Family", "Familie"),
+        ("Weight", "Gewicht"),
+        ("Slant", "Cursief"),
+        ("Effects", "Effect"),
+        ("Preview", "Voorbeeld"),
+        ("Size", "Grootte"),
+        ("Should be a of data type", "Moet zijn van type"),
+        ("Invalid data type", "Verkeerd type"),
+        ("Number cannot be greater than", "Nummer kan niet groter zijn dan"),
+        ("Out of range", "Buiten bereik"),
+        ("Previous", "Vorige"),
+        ("The quick brown fox jumps over the lazy dog.",
+         "The quick brown fox jumps over the lazy dog.\n"
+         "Filmquiz bracht knappe ex-yogi van de wijs.\n"
+         "Pa's wijze lynx bezag vroom het fikse aquaduct."),
+        ("Font Selector", "Lettertypekeuze"),
+        ("normal", "normaal"),
+        ("bold", "vet"),
+        ("negrito", "zwart"),
+        ("roman", "normaal"),
+        ("italic", "cursief"),
+        ("underline", "onderstreept"),
+        ("overstrike", "doorhalen"),
+        ("Color Chooser", "Kleurkeuze"),
+        ("Advanced", "Geavanceerd"),
+        ("Themed", "Thema"),
+        ("Standard", "Standaard"),
+        ("Current", "Huidig"),
+        ("New", "Nieuw"),
+        ("Hue", "Tint"),
+        ("Sat", "Verzadiging"),
+        ("Lum", "Helderheid"),
+        ("Hex", "Hex"),
+        ("Red", "Rood"),
+        ("Green", "Groen"),
+        ("Blue", "Blauw"),
+        ("color dropper", "Kleurenkiezer"),
+        ("Cancel", "Annuleren"),
+        ("Search", "Zoeken"),
+        ("Page", "Pagina"),
+        ("of", "van"),
+        ("⎌", "⎌"),
+        ("Reset table", "Tabel resetten"),
+        ("Columns", "Kolommen"),
+        ("Move", "Verplaatsen"),
+        ("Align", "Uitlijnen"),
+        ("Hide column", "Kolom verbergen"),
+        ("Delete column", "Kolom verwijderen"),
+        ("Show All", "Alle tonen"),
+        ("Move to left", "Verplaats naar links"),
+        ("Move to right", "Verplaats naar rechts"),
+        ("Move to first", "Verplaats naar begin"),
+        ("Move to last", "Verplaats naar eind"),
+        ("Align left", "Links uitlijnen"),
+        ("Align center", "Centreren"),
+        ("Align right", "Rechts uitlijnen"),
+        ("Sort", "Sorteren"),
+        ("Filter", "Filteren"),
+        ("Export", "Exporteren"),
+        ("Delete selected rows", "Verwijder geselecteerde rijen"),
+        ("Sort Ascending", "Sorteer oplopend"),
+        ("Sort Descending", "Sorteer aflopend"),
+        ("Clear filters", "Filters wissen"),
+        ("Filter by cell's value", "Filteren op celinhoud"),
+        ("Hide select rows", "Rijen verbergen"),
+        ("Show only select rows", "Alleen geselecteerde rijen weergeven"),
+        ("Export all records", "Alle data exporteren"),
+        ("Export current page", "Huidige pagina exporteren"),
+        ("Export current selection", "Huidge selectie exporteren"),
+        ("Export records in filter", "Alle gefilterde data exporteren"),
+        ("Move up", "Naar boven"),
+        ("Move down", "Naar beneden"),
+        ("Move to top", "Naar het begin"),
+        ("Move to bottom", "Naar het eind"),
+        ("Mo", "Ma"),
+        ("Tu", "Di"),
+        ("We", "Wo"),
+        ("Th", "Do"),
+        ("Fr", "Vr"),
+        ("Sa", "Za"),
+        ("Su", "Zo"),
+    )
+)
