@@ -427,6 +427,11 @@ class ScrolledFrame(ttk.Frame):
         frame."""
         self.autohide = not self.autohide
 
+    def destroy(self):
+        self.vscroll.destroy()
+        super().destroy()
+        self.container.destroy()
+
     def _measures(self):
         """Measure the base size of the container and the thumb size
         for use in the yview methods"""
