@@ -110,7 +110,7 @@ class TableColumn:
     @property
     def tableindex(self):
         """The index of the column as it is in the table configuration."""
-        cols = self.view.configure("columns")
+        cols = self.view.cget("columns")
         if cols is None:
             return
         try:
@@ -121,7 +121,7 @@ class TableColumn:
     @property
     def displayindex(self):
         """The index of the column as it is displayed"""
-        cols = self.view.configure("displaycolumns")
+        cols = self.view.cget("displaycolumns")
         if "#all" in cols:
             return self.tableindex
         else:
@@ -164,20 +164,20 @@ class TableColumn:
 
     def show(self):
         """Make the column visible in the tableview"""
-        displaycols = list(self.view.configure("displaycolumns"))
+        displaycols = list(self.view.cget("displaycolumns"))
         if "#all" in displaycols:
             return
         if self.cid in displaycols:
             return
-        columns = list(self.view.configure("columns"))
+        columns = list(self.view.cget("columns"))
         index = columns.index(self.cid)
         displaycols.insert(index, self.cid)
         self.view.configure(displaycolumns=displaycols)
 
     def hide(self):
         """Hide the column in the tableview"""
-        displaycols = list(self.view.configure("displaycolumns"))
-        cols = list(self.view.configure("columns"))
+        displaycols = list(self.view.cget("displaycolumns"))
+        cols = list(self.view.cget("columns"))
         if "#all" in displaycols:
             displaycols = cols
         displaycols.remove(self.cid)
@@ -251,7 +251,7 @@ class TableRow:
                 A list of values to display in the row
         """
         self.view: ttk.Treeview = tableview.view
-        self._values = values
+        self._values = list(values)
         self._iid = None
         self._sort = TableRow._cnt + 1
         self._table = tableview
@@ -433,6 +433,7 @@ class Tableview(ttk.Frame):
             rowdata=[],
             paginated=False,
             searchable=False,
+            yscrollbar=False,
             autofit=False,
             autoalign=True,
             stripecolor=None,
@@ -481,6 +482,10 @@ class Tableview(ttk.Frame):
                 bar. Currently, the search method looks for any row
                 that contains the search text. The filtered results
                 are displayed in the table view.
+                
+            yscrollbar (bool):
+                If `True`, a vertical scrollbar will be created to the right
+                of the table.
 
             autofit (bool):
                 If `True`, the table columns will be automatically sized
@@ -530,6 +535,7 @@ class Tableview(ttk.Frame):
         self._pagesize = tk.IntVar(value=pagesize)
         self._paginated = paginated
         self._searchable = searchable
+        self._yscrollbar = yscrollbar
         self._stripecolor = stripecolor
         self._autofit = autofit
         self._autoalign = autoalign
@@ -1388,7 +1394,7 @@ class Tableview(ttk.Frame):
 
     def reset_column_sort(self):
         """Display all columns by original insert index"""
-        cols = sorted([col.cid for col in self.tablecolumns_visible])
+        cols = sorted([col.cid for col in self.tablecolumns_visible], key=int)
         self.view.configure(displaycolumns=cols)
 
     def reset_table(self):
@@ -2075,16 +2081,27 @@ class Tableview(ttk.Frame):
         """Build the data table"""
         if self._searchable:
             self._build_search_frame()
+            
+        table_frame = ttk.Frame(self)
+        table_frame.pack(fill=BOTH, expand=YES, side=TOP)
 
         self.view = ttk.Treeview(
-            master=self,
+            master=table_frame,
             columns=[x for x in range(len(coldata))],
             height=self._height,
             selectmode=EXTENDED,
             show=HEADINGS,
             bootstyle=f"{bootstyle}-table",
         )
-        self.view.pack(fill=BOTH, expand=YES, side=TOP)
+        self.view.pack(fill=BOTH, expand=YES, side=LEFT)
+        
+        if self._yscrollbar:
+            self.ybar = ttk.Scrollbar(
+                master=table_frame, command=self.view.yview, orient=VERTICAL
+            )
+            self.ybar.pack(fill=Y, side=RIGHT)
+            self.view.configure(yscrollcommand=self.ybar.set)
+        
         self.hbar = ttk.Scrollbar(
             master=self, command=self.view.xview, orient=HORIZONTAL
         )
